Class: Spotted::Models::ArtistListAlbumsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::ArtistListAlbumsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/spotted/models/artist_list_albums_params.rb
Overview
Instance Attribute Summary collapse
-
#include_groups ⇒ String?
A comma-separated list of keywords that will be used to filter the response.
-
#limit ⇒ Integer?
The maximum number of items to return.
- #market ⇒ String?
-
#offset ⇒ Integer?
The index of the first item to return.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(include_groups: nil, limit: nil, market: nil, offset: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ArtistListAlbumsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(include_groups: nil, limit: nil, market: nil, offset: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Spotted::Models::ArtistListAlbumsParams for more details.
|
|
# File 'lib/spotted/models/artist_list_albums_params.rb', line 46
|
Instance Attribute Details
#include_groups ⇒ String?
A comma-separated list of keywords that will be used to filter the response. If
not supplied, all album types will be returned.
Valid values are:
-
album<br/>- single<br/>- appears_on<br/>- compilation<br/>For example:
include_groups=album,single.
17 |
# File 'lib/spotted/models/artist_list_albums_params.rb', line 17 optional :include_groups, String |
#limit ⇒ Integer?
The maximum number of items to return. Default: 5. Minimum: 1. Maximum: 10.
23 |
# File 'lib/spotted/models/artist_list_albums_params.rb', line 23 optional :limit, Integer |
#market ⇒ String?
An
ISO 3166-1 alpha-2 country code.
If a country code is specified, only content that is available in that market
will be returned.
If a valid user access token is specified in the request
header, the country associated with the user account will take priority over
this parameter.
_Note: If neither market or user country are provided,
the content is considered unavailable for the client._
Users can view the
country that is associated with their account in the
account settings.
37 |
# File 'lib/spotted/models/artist_list_albums_params.rb', line 37 optional :market, String |
#offset ⇒ Integer?
The index of the first item to return. Default: 0 (the first item). Use with limit to get the next set of items.
44 |
# File 'lib/spotted/models/artist_list_albums_params.rb', line 44 optional :offset, Integer |