Class: Spotted::Models::ArtistListAlbumsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/artist_list_albums_response.rb

Overview

Defined Under Namespace

Modules: AlbumGroup, AlbumType, ReleaseDatePrecision

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, album_group:, album_type:, artists:, available_markets:, external_urls:, href:, images:, name:, release_date:, release_date_precision:, total_tracks:, uri:, published: nil, restrictions: nil, type: :album) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::ArtistListAlbumsResponse for more details.

Parameters:



# File 'lib/spotted/models/artist_list_albums_response.rb', line 119

Instance Attribute Details

#album_group ⇒ Symbol, Spotted::Models::ArtistListAlbumsResponse::AlbumGroup

Deprecated.

This field describes the relationship between the artist and the album.



20
# File 'lib/spotted/models/artist_list_albums_response.rb', line 20

required :album_group, enum: -> { Spotted::Models::ArtistListAlbumsResponse::AlbumGroup }

#album_type ⇒ Symbol, Spotted::Models::ArtistListAlbumsResponse::AlbumType

The type of the album.



26
# File 'lib/spotted/models/artist_list_albums_response.rb', line 26

required :album_type, enum: -> { Spotted::Models::ArtistListAlbumsResponse::AlbumType }

#artists ⇒ Array<Spotted::Models::SimplifiedArtistObject>

The artists of the album. Each artist object includes a link in href to more detailed information about the artist.



33
# File 'lib/spotted/models/artist_list_albums_response.rb', line 33

required :artists, -> { Spotted::Internal::Type::ArrayOf[Spotted::SimplifiedArtistObject] }

#available_markets ⇒ Array<String>

Deprecated.

The markets in which the album is available: ISO 3166-1 alpha-2 country codes. NOTE: an album is considered available in a market when at least 1 of its tracks is available in that market.

Returns:

  • (Array<String>)


44
# File 'lib/spotted/models/artist_list_albums_response.rb', line 44

required :available_markets, Spotted::Internal::Type::ArrayOf[String]

#external_urls ⇒ Spotted::Models::ExternalURLObject

Known external URLs for this album.



50
# File 'lib/spotted/models/artist_list_albums_response.rb', line 50

required :external_urls, -> { Spotted::ExternalURLObject }

#href ⇒ String

A link to the Web API endpoint providing full details of the album.

Returns:

  • (String)


56
# File 'lib/spotted/models/artist_list_albums_response.rb', line 56

required :href, String

#id ⇒ String

The Spotify ID for the album.

Returns:

  • (String)


12
# File 'lib/spotted/models/artist_list_albums_response.rb', line 12

required :id, String

#images ⇒ Array<Spotted::Models::ImageObject>

The cover art for the album in various sizes, widest first.

Returns:



62
# File 'lib/spotted/models/artist_list_albums_response.rb', line 62

required :images, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] }

#name ⇒ String

The name of the album. In case of an album takedown, the value may be an empty string.

Returns:

  • (String)


69
# File 'lib/spotted/models/artist_list_albums_response.rb', line 69

required :name, String

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


111
# File 'lib/spotted/models/artist_list_albums_response.rb', line 111

optional :published, Spotted::Internal::Type::Boolean

#release_date ⇒ String

The date the album was first released.

Returns:

  • (String)


75
# File 'lib/spotted/models/artist_list_albums_response.rb', line 75

required :release_date, String

#release_date_precision ⇒ Symbol, Spotted::Models::ArtistListAlbumsResponse::ReleaseDatePrecision

The precision with which release_date value is known.



81
82
# File 'lib/spotted/models/artist_list_albums_response.rb', line 81

required :release_date_precision,
enum: -> { Spotted::Models::ArtistListAlbumsResponse::ReleaseDatePrecision }

#restrictions ⇒ Spotted::Models::AlbumRestrictionObject?

Included in the response when a content restriction is applied.



117
# File 'lib/spotted/models/artist_list_albums_response.rb', line 117

optional :restrictions, -> { Spotted::AlbumRestrictionObject }

#total_tracks ⇒ Integer

The number of tracks in the album.

Returns:

  • (Integer)


88
# File 'lib/spotted/models/artist_list_albums_response.rb', line 88

required :total_tracks, Integer

#type ⇒ Symbol, :album

The object type.

Returns:

  • (Symbol, :album)


94
# File 'lib/spotted/models/artist_list_albums_response.rb', line 94

required :type, const: :album

#uri ⇒ String

The Spotify URI for the album.

Returns:

  • (String)


101
# File 'lib/spotted/models/artist_list_albums_response.rb', line 101

required :uri, String

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/spotted/models/artist_list_albums_response.rb', line 168