Class: Spotted::Models::AudiobookBase

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/audiobook_base.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, authors:, available_markets:, copyrights:, description:, explicit:, external_urls:, href:, html_description:, images:, languages:, media_type:, name:, narrators:, publisher:, total_chapters:, uri:, edition: nil, published: nil, type: :audiobook) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::AudiobookBase for more details.

Parameters:

  • id (String) —

    The Spotify ID for the audio

  • authors (Array<Spotted::Models::AuthorObject>) —

    The author(s) for the audiobook.

  • available_markets (Array<String>) —

    A list of the countries in which the audiobook can be played, identified by thei

  • copyrights (Array<Spotted::Models::CopyrightObject>) —

    The copyright statements of the audiobook.

  • description (String) —

    A description of the audiobook. HTML tags are stripped away from this field, use

  • explicit (Boolean) —

    Whether or not the audiobook has explicit content (true = yes it does; false = n

  • external_urls (Spotted::Models::ExternalURLObject) —

    External URLs for this audiobook.

  • href (String) —

    A link to the Web API endpoint providing full details of the audiobook.

  • html_description (String) —

    A description of the audiobook. This field may contain HTML tags.

  • images (Array<Spotted::Models::ImageObject>) —

    The cover art for the audiobook in various sizes, widest first.

  • languages (Array<String>) —

    A list of the languages used in the audiobook, identified by their [ISO 639](htt

  • media_type (String) —

    The media type of the audiobook.

  • name (String) —

    The name of the audiobook.

  • narrators (Array<Spotted::Models::NarratorObject>) —

    The narrator(s) for the audiobook.

  • publisher (String) —

    The publisher of the audiobook.

  • total_chapters (Integer) —

    The number of chapters in this audiobook.

  • uri (String) —

    The Spotify URI for the audi

  • edition (String) (defaults to: nil) —

    The edition of the audiobook.

  • published (Boolean) (defaults to: nil) —

    The playlist's public/private status (if it should be added to the user's profil

  • type (Symbol, :audiobook) (defaults to: :audiobook) —

    The object type.



# File 'lib/spotted/models/audiobook_base.rb', line 141

Instance Attribute Details

#authors ⇒ Array<Spotted::Models::AuthorObject>

The author(s) for the audiobook.

Returns:



17
# File 'lib/spotted/models/audiobook_base.rb', line 17

required :authors, -> { Spotted::Internal::Type::ArrayOf[Spotted::AuthorObject] }

#available_markets ⇒ Array<String>

Deprecated.

A list of the countries in which the audiobook can be played, identified by their ISO 3166-1 alpha-2 code.

Returns:

  • (Array<String>)


27
# File 'lib/spotted/models/audiobook_base.rb', line 27

required :available_markets, Spotted::Internal::Type::ArrayOf[String]

#copyrights ⇒ Array<Spotted::Models::CopyrightObject>

The copyright statements of the audiobook.



33
# File 'lib/spotted/models/audiobook_base.rb', line 33

required :copyrights, -> { Spotted::Internal::Type::ArrayOf[Spotted::CopyrightObject] }

#description ⇒ String

A description of the audiobook. HTML tags are stripped away from this field, use html_description field in case HTML tags are needed.

Returns:

  • (String)


40
# File 'lib/spotted/models/audiobook_base.rb', line 40

required :description, String

#edition ⇒ String?

The edition of the audiobook.

Returns:

  • (String, nil)


129
# File 'lib/spotted/models/audiobook_base.rb', line 129

optional :edition, String

#explicit ⇒ Boolean

Whether or not the audiobook has explicit content (true = yes it does; false = no it does not OR unknown).

Returns:

  • (Boolean)


47
# File 'lib/spotted/models/audiobook_base.rb', line 47

required :explicit, Spotted::Internal::Type::Boolean

#external_urls ⇒ Spotted::Models::ExternalURLObject

External URLs for this audiobook.



53
# File 'lib/spotted/models/audiobook_base.rb', line 53

required :external_urls, -> { Spotted::ExternalURLObject }

#href ⇒ String

A link to the Web API endpoint providing full details of the audiobook.

Returns:

  • (String)


59
# File 'lib/spotted/models/audiobook_base.rb', line 59

required :href, String

#html_description ⇒ String

A description of the audiobook. This field may contain HTML tags.

Returns:

  • (String)


65
# File 'lib/spotted/models/audiobook_base.rb', line 65

required :html_description, String

#id ⇒ String

The Spotify ID for the audiobook.

Returns:

  • (String)


11
# File 'lib/spotted/models/audiobook_base.rb', line 11

required :id, String

#images ⇒ Array<Spotted::Models::ImageObject>

The cover art for the audiobook in various sizes, widest first.

Returns:



71
# File 'lib/spotted/models/audiobook_base.rb', line 71

required :images, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] }

#languages ⇒ Array<String>

A list of the languages used in the audiobook, identified by their ISO 639 code.

Returns:

  • (Array<String>)


78
# File 'lib/spotted/models/audiobook_base.rb', line 78

required :languages, Spotted::Internal::Type::ArrayOf[String]

#media_type ⇒ String

The media type of the audiobook.

Returns:

  • (String)


84
# File 'lib/spotted/models/audiobook_base.rb', line 84

required :media_type, String

#name ⇒ String

The name of the audiobook.

Returns:

  • (String)


90
# File 'lib/spotted/models/audiobook_base.rb', line 90

required :name, String

#narrators ⇒ Array<Spotted::Models::NarratorObject>

The narrator(s) for the audiobook.



96
# File 'lib/spotted/models/audiobook_base.rb', line 96

required :narrators, -> { Spotted::Internal::Type::ArrayOf[Spotted::NarratorObject] }

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


139
# File 'lib/spotted/models/audiobook_base.rb', line 139

optional :published, Spotted::Internal::Type::Boolean

#publisher ⇒ String

Deprecated.

The publisher of the audiobook.

Returns:

  • (String)


104
# File 'lib/spotted/models/audiobook_base.rb', line 104

required :publisher, String

#total_chapters ⇒ Integer

The number of chapters in this audiobook.

Returns:

  • (Integer)


110
# File 'lib/spotted/models/audiobook_base.rb', line 110

required :total_chapters, Integer

#type ⇒ Symbol, :audiobook

The object type.

Returns:

  • (Symbol, :audiobook)


116
# File 'lib/spotted/models/audiobook_base.rb', line 116

required :type, const: :audiobook

#uri ⇒ String

The Spotify URI for the audiobook.

Returns:

  • (String)


123
# File 'lib/spotted/models/audiobook_base.rb', line 123

required :uri, String