Class: Spotted::Models::Browse::CategoryListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/browse/category_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, href:, icons:, name:, published: nil) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::Browse::CategoryListResponse for more details.

Parameters:

  • id (String) —
  • href (String) —

    A link to the Web API endpoint returning full details of the category.

  • icons (Array<Spotted::Models::ImageObject>) —

    The category icon, in various sizes.

  • name (String) —

    The name of the category.

  • published (Boolean) (defaults to: nil) —

    The playlist's public/private status (if it should be added to the user's profil



# File 'lib/spotted/models/browse/category_list_response.rb', line 43

Instance Attribute Details

#href ⇒ String

A link to the Web API endpoint returning full details of the category.

Returns:

  • (String)


19
# File 'lib/spotted/models/browse/category_list_response.rb', line 19

required :href, String

#icons ⇒ Array<Spotted::Models::ImageObject>

The category icon, in various sizes.

Returns:



25
# File 'lib/spotted/models/browse/category_list_response.rb', line 25

required :icons, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] }

#id ⇒ String

The Spotify category ID of the category.

Returns:

  • (String)


13
# File 'lib/spotted/models/browse/category_list_response.rb', line 13

required :id, String

#name ⇒ String

The name of the category.

Returns:

  • (String)


31
# File 'lib/spotted/models/browse/category_list_response.rb', line 31

required :name, String

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


41
# File 'lib/spotted/models/browse/category_list_response.rb', line 41

optional :published, Spotted::Internal::Type::Boolean