Class: Spotted::Models::Browse::CategoryRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::Browse::CategoryRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/spotted/models/browse/category_retrieve_params.rb
Overview
Instance Attribute Summary collapse
-
#locale ⇒ String?
The desired language, consisting of an ISO 639-1 language code and an ISO 3166-1 alpha-2 country code, joined by an underscore.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(locale: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CategoryRetrieveParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(locale: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Spotted::Models::Browse::CategoryRetrieveParams for more details.
|
|
# File 'lib/spotted/models/browse/category_retrieve_params.rb', line 24
|
Instance Attribute Details
#locale ⇒ String?
The desired language, consisting of an
ISO 639-1 language code and an
ISO 3166-1 alpha-2 country code,
joined by an underscore. For example: es_MX, meaning "Spanish
(Mexico)". Provide this parameter if you want the category strings returned
in a particular language.
Note: if locale is not supplied, or if the
specified language is not available, the category strings returned will be in
the Spotify default language (American English).
22 |
# File 'lib/spotted/models/browse/category_retrieve_params.rb', line 22 optional :locale, String |