Class: Spotted::Models::ChapterBulkRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/spotted/models/chapter_bulk_retrieve_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ids:, market: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::ChapterBulkRetrieveParams for more details.

Parameters:



# File 'lib/spotted/models/chapter_bulk_retrieve_params.rb', line 32

Instance Attribute Details

#ids ⇒ String

A comma-separated list of the Spotify IDs. For example: ids=0IsXVP0JmcB2adSE338GkK,3ZXb8FKZGU0EHALYX6uCzU. Maximum: 50 IDs.

Returns:

  • (String)


16
# File 'lib/spotted/models/chapter_bulk_retrieve_params.rb', line 16

required :ids, String

#market ⇒ String?

An ISO 3166-1 alpha-2 country code. If a country code is specified, only content that is available in that market will be returned.
If a valid user access token is specified in the request header, the country associated with the user account will take priority over this parameter.
_Note: If neither market or user country are provided, the content is considered unavailable for the client._
Users can view the country that is associated with their account in the account settings.

Returns:

  • (String, nil)


30
# File 'lib/spotted/models/chapter_bulk_retrieve_params.rb', line 30

optional :market, String