Class: Spotted::Models::Me::AlbumListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/spotted/models/me/album_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(limit: nil, market: nil, offset: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::Me::AlbumListParams for more details.

Parameters:

  • limit (Integer) (defaults to: nil) —

    The maximum number of items to return. Default: 20. Minimum: 1. Maximum: 50.

  • market (String) (defaults to: nil) —

    An [ISO 3166-1 alpha-2 country code](https://en.wikipedia.org/wiki/ISO_3166-1_al

  • offset (Integer) (defaults to: nil) —

    The index of the first item to return. Default: 0 (the first item). Use with lim

  • request_options (Spotted::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/spotted/models/me/album_list_params.rb', line 38

Instance Attribute Details

#limit ⇒ Integer?

The maximum number of items to return. Default: 20. Minimum: 1. Maximum: 50.

Returns:

  • (Integer, nil)


15
# File 'lib/spotted/models/me/album_list_params.rb', line 15

optional :limit, Integer

#market ⇒ String?

An ISO 3166-1 alpha-2 country code. If a country code is specified, only content that is available in that market will be returned.
If a valid user access token is specified in the request header, the country associated with the user account will take priority over this parameter.
_Note: If neither market or user country are provided, the content is considered unavailable for the client._
Users can view the country that is associated with their account in the account settings.

Returns:

  • (String, nil)


29
# File 'lib/spotted/models/me/album_list_params.rb', line 29

optional :market, String

#offset ⇒ Integer?

The index of the first item to return. Default: 0 (the first item). Use with limit to get the next set of items.

Returns:

  • (Integer, nil)


36
# File 'lib/spotted/models/me/album_list_params.rb', line 36

optional :offset, Integer