Class: Spotted::Models::Me::PlayerGetCurrentlyPlayingResponse::Actions

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/me/player_get_currently_playing_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Spotted::Internal::Type::BaseModel

Instance Attribute Details

#interrupting_playback ⇒ Boolean?

Interrupting playback. Optional field.

Returns:

  • (Boolean, nil)


88
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 88

optional :interrupting_playback, Spotted::Internal::Type::Boolean

#pausing ⇒ Boolean?

Pausing. Optional field.

Returns:

  • (Boolean, nil)


94
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 94

optional :pausing, Spotted::Internal::Type::Boolean

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


104
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 104

optional :published, Spotted::Internal::Type::Boolean

#resuming ⇒ Boolean?

Resuming. Optional field.

Returns:

  • (Boolean, nil)


110
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 110

optional :resuming, Spotted::Internal::Type::Boolean

#seeking ⇒ Boolean?

Seeking playback location. Optional field.

Returns:

  • (Boolean, nil)


116
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 116

optional :seeking, Spotted::Internal::Type::Boolean

#skipping_next ⇒ Boolean?

Skipping to the next context. Optional field.

Returns:

  • (Boolean, nil)


122
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 122

optional :skipping_next, Spotted::Internal::Type::Boolean

#skipping_prev ⇒ Boolean?

Skipping to the previous context. Optional field.

Returns:

  • (Boolean, nil)


128
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 128

optional :skipping_prev, Spotted::Internal::Type::Boolean

#toggling_repeat_context ⇒ Boolean?

Toggling repeat context flag. Optional field.

Returns:

  • (Boolean, nil)


134
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 134

optional :toggling_repeat_context, Spotted::Internal::Type::Boolean

#toggling_repeat_track ⇒ Boolean?

Toggling repeat track flag. Optional field.

Returns:

  • (Boolean, nil)


140
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 140

optional :toggling_repeat_track, Spotted::Internal::Type::Boolean

#toggling_shuffle ⇒ Boolean?

Toggling shuffle flag. Optional field.

Returns:

  • (Boolean, nil)


146
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 146

optional :toggling_shuffle, Spotted::Internal::Type::Boolean

#transferring_playback ⇒ Boolean?

Transfering playback between devices. Optional field.

Returns:

  • (Boolean, nil)


152
# File 'lib/spotted/models/me/player_get_currently_playing_response.rb', line 152

optional :transferring_playback, Spotted::Internal::Type::Boolean