Class: Spotted::Models::Me::PlayerTransferParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::Me::PlayerTransferParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/spotted/models/me/player_transfer_params.rb
Overview
Instance Attribute Summary collapse
-
#device_ids ⇒ Array<String>
A JSON array containing the ID of the device on which playback should be started/transferred.
For example:{device_ids:["74ASZWbe4lXaubB36ztrGX"]}<br/>_Note: Although an array is accepted, only a single device_id is currently supported. -
#play ⇒ Boolean?
true: ensure playback happens on new device.
false or not provided: keep the current playback state. -
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's profile or not):
truethe playlist will be public,falsethe playlist will be private,nullthe playlist status is not relevant.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(device_ids:, play: nil, published: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PlayerTransferParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(device_ids:, play: nil, published: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Spotted::Models::Me::PlayerTransferParams for more details.
|
|
# File 'lib/spotted/models/me/player_transfer_params.rb', line 38
|
Instance Attribute Details
#device_ids ⇒ Array<String>
A JSON array containing the ID of the device on which playback should be
started/transferred.
For
example:{device_ids:["74ASZWbe4lXaubB36ztrGX"]}<br/>Note: Although an
array is accepted, only a single device_id is currently supported. Supplying
more than one will return 400 Bad Request
19 |
# File 'lib/spotted/models/me/player_transfer_params.rb', line 19 required :device_ids, Spotted::Internal::Type::ArrayOf[String] |
#play ⇒ Boolean?
true: ensure playback happens on new device.
false or not provided:
keep the current playback state.
26 |
# File 'lib/spotted/models/me/player_transfer_params.rb', line 26 optional :play, Spotted::Internal::Type::Boolean |
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's
profile or not): true the playlist will be public, false the playlist will
be private, null the playlist status is not relevant. For more about
public/private status, see
Working with Playlists
36 |
# File 'lib/spotted/models/me/player_transfer_params.rb', line 36 optional :published, Spotted::Internal::Type::Boolean |