Class: Spotted::Models::MeRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/me_retrieve_response.rb

Overview

Defined Under Namespace

Classes: ExplicitContent

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, country: nil, display_name: nil, email: nil, explicit_content: nil, external_urls: nil, followers: nil, href: nil, images: nil, product: nil, published: nil, type: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::MeRetrieveResponse for more details.

_*

cur

Parameters:

  • id (String) (defaults to: nil) —

    The Spotify user ID for the

  • country (String) (defaults to: nil) —

    The country of the user, as set in the user's account profile. An [ISO 3166-1 al

  • display_name (String) (defaults to: nil) —

    The name displayed on the user's profile. null if not available.

  • email (String) (defaults to: nil) —

    The user's email address, as entered by the user when creating their account.

  • explicit_content (Spotted::Models::MeRetrieveResponse::ExplicitContent) (defaults to: nil) —

    The user's explicit content settings. _This field is only available when the

  • external_urls (Spotted::Models::ExternalURLObject) (defaults to: nil) —

    Known external URLs for this user.

  • followers (Spotted::Models::FollowersObject) (defaults to: nil) —

    Information about the followers of the user.

  • href (String) (defaults to: nil) —

    A link to the Web API endpoint for this user.

  • images (Array<Spotted::Models::ImageObject>) (defaults to: nil) —

    The user's profile image.

  • product (String) (defaults to: nil) —

    The user's Spotify subscription level: "premium", "free", etc. (The subscription

  • published (Boolean) (defaults to: nil) —

    The playlist's public/private status (if it should be added to the user's profil

  • type (String) (defaults to: nil) —

    The object type: "user"

  • uri (String) (defaults to: nil) —

    The Spotify URI for the user



# File 'lib/spotted/models/me_retrieve_response.rb', line 117

Instance Attribute Details

#country ⇒ String?

Deprecated.

The country of the user, as set in the user's account profile. An ISO 3166-1 alpha-2 country code. This field is only available when the current user has granted access to the user-read-private scope.

Returns:

  • (String, nil)


24
# File 'lib/spotted/models/me_retrieve_response.rb', line 24

optional :country, String

#display_name ⇒ String?

The name displayed on the user's profile. null if not available.

Returns:

  • (String, nil)


30
# File 'lib/spotted/models/me_retrieve_response.rb', line 30

optional :display_name, String

#email ⇒ String?

Deprecated.

The user's email address, as entered by the user when creating their account. Important! This email address is unverified; there is no proof that it actually belongs to the user. This field is only available when the current user has granted access to the user-read-email scope.

Returns:

  • (String, nil)


43
# File 'lib/spotted/models/me_retrieve_response.rb', line 43

optional :email, String

#explicit_content ⇒ Spotted::Models::MeRetrieveResponse::ExplicitContent?

Deprecated.

The user's explicit content settings. This field is only available when the current user has granted access to the user-read-private scope.



54
# File 'lib/spotted/models/me_retrieve_response.rb', line 54

optional :explicit_content, -> { Spotted::Models::MeRetrieveResponse::ExplicitContent }

#external_urls ⇒ Spotted::Models::ExternalURLObject?

Known external URLs for this user.



60
# File 'lib/spotted/models/me_retrieve_response.rb', line 60

optional :external_urls, -> { Spotted::ExternalURLObject }

#followers ⇒ Spotted::Models::FollowersObject?

Deprecated.

Information about the followers of the user.



68
# File 'lib/spotted/models/me_retrieve_response.rb', line 68

optional :followers, -> { Spotted::FollowersObject }

#href ⇒ String?

A link to the Web API endpoint for this user.

Returns:

  • (String, nil)


74
# File 'lib/spotted/models/me_retrieve_response.rb', line 74

optional :href, String

#id ⇒ String?

The Spotify user ID for the user.

Returns:

  • (String, nil)


12
# File 'lib/spotted/models/me_retrieve_response.rb', line 12

optional :id, String

#images ⇒ Array<Spotted::Models::ImageObject>?

The user's profile image.

Returns:



80
# File 'lib/spotted/models/me_retrieve_response.rb', line 80

optional :images, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] }

#product ⇒ String?

Deprecated.

The user's Spotify subscription level: "premium", "free", etc. (The subscription level "open" can be considered the same as "free".) This field is only available when the current user has granted access to the user-read-private scope.

Returns:

  • (String, nil)


92
# File 'lib/spotted/models/me_retrieve_response.rb', line 92

optional :product, String

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


102
# File 'lib/spotted/models/me_retrieve_response.rb', line 102

optional :published, Spotted::Internal::Type::Boolean

#type ⇒ String?

The object type: "user"

Returns:

  • (String, nil)


108
# File 'lib/spotted/models/me_retrieve_response.rb', line 108

optional :type, String

#uri ⇒ String?

The Spotify URI for the user.

Returns:

  • (String, nil)


115
# File 'lib/spotted/models/me_retrieve_response.rb', line 115

optional :uri, String