Class: Spotted::Models::PlaylistRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/spotted/models/playlist_retrieve_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(additional_types: nil, fields: nil, market: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::PlaylistRetrieveParams for more details.

Parameters:

  • additional_types (String) (defaults to: nil) —

    A comma-separated list of item types that your client supports besides the defau

  • fields (String) (defaults to: nil) —

    Filters for the query: a comma-separated list of the

  • market (String) (defaults to: nil) —

    An [ISO 3166-1 alpha-2 country code](https://en.wikipedia.org/wiki/ISO_3166-1_al

  • request_options (Spotted::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/spotted/models/playlist_retrieve_params.rb', line 50

Instance Attribute Details

#additional_types ⇒ String?

A comma-separated list of item types that your client supports besides the default track type. Valid types are: track and episode.
_Note: This parameter was introduced to allow existing clients to maintain their current behaviour and might be deprecated in the future._
In addition to providing this parameter, make sure that your client properly handles cases of new types in the future by checking against the type field of each object.

Returns:

  • (String, nil)


19
# File 'lib/spotted/models/playlist_retrieve_params.rb', line 19

optional :additional_types, String

#fields ⇒ String?

Filters for the query: a comma-separated list of the fields to return. If omitted, all fields are returned. For example, to get just the playlist''s description and URI: fields=description,uri. A dot separator can be used to specify non-reoccurring fields, while parentheses can be used to specify reoccurring fields within objects. For example, to get just the added date and user ID of the adder: fields=tracks.items(added_at,added_by.id). Use multiple parentheses to drill down into nested objects, for example: fields=tracks.items(track(name,href,album(name,href))). Fields can be excluded by prefixing them with an exclamation mark, for example: fields=tracks.items(track(name,href,album(!name,href)))

Returns:

  • (String, nil)


34
# File 'lib/spotted/models/playlist_retrieve_params.rb', line 34

optional :fields, String

#market ⇒ String?

An ISO 3166-1 alpha-2 country code. If a country code is specified, only content that is available in that market will be returned.
If a valid user access token is specified in the request header, the country associated with the user account will take priority over this parameter.
_Note: If neither market or user country are provided, the content is considered unavailable for the client._
Users can view the country that is associated with their account in the account settings.

Returns:

  • (String, nil)


48
# File 'lib/spotted/models/playlist_retrieve_params.rb', line 48

optional :market, String