Class: Spotted::Models::PlaylistRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/playlist_retrieve_response.rb

Overview

Defined Under Namespace

Classes: Items, Owner, Tracks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(display_name: nil) ⇒ Object

Some parameter documentations has been truncated, see Owner for more details.

The user who owns the playlist

Parameters:

  • display_name (String, nil) (defaults to: nil) —

    The name displayed on the user's profile. null if not available.



# File 'lib/spotted/models/playlist_retrieve_response.rb', line 112

Instance Attribute Details

#collaborative ⇒ Boolean?

true if the owner allows other users to modify the playlist.

Returns:

  • (Boolean, nil)


18
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 18

optional :collaborative, Spotted::Internal::Type::Boolean

#description ⇒ String?

The playlist description. Only returned for modified, verified playlists, otherwise null.

Returns:

  • (String, nil)


25
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 25

optional :description, String, nil?: true

#external_urls ⇒ Spotted::Models::ExternalURLObject?

Known external URLs for this playlist.



31
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 31

optional :external_urls, -> { Spotted::ExternalURLObject }

#followers ⇒ Spotted::Models::FollowersObject?

Information about the followers of the playlist.



37
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 37

optional :followers, -> { Spotted::FollowersObject }

#href ⇒ String?

A link to the Web API endpoint providing full details of the playlist.

Returns:

  • (String, nil)


43
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 43

optional :href, String

#id ⇒ String?

The Spotify ID for the playlist.

Returns:

  • (String, nil)


12
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 12

optional :id, String

#images ⇒ Array<Spotted::Models::ImageObject>?

Images for the playlist. The array may be empty or contain up to three images. The images are returned by size in descending order. See Working with Playlists. Note: If returned, the source URL for the image (url) is temporary and will expire in less than a day.

Returns:



53
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 53

optional :images, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] }

#items ⇒ Spotted::Models::PlaylistRetrieveResponse::Items?

The items of the playlist. Note: This field is only available for playlists owned by the current user or playlists the user is a collaborator of.



60
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 60

optional :items, -> { Spotted::Models::PlaylistRetrieveResponse::Items }

#name ⇒ String?

The name of the playlist.

Returns:

  • (String, nil)


66
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 66

optional :name, String

#owner ⇒ Spotted::Models::PlaylistRetrieveResponse::Owner?

The user who owns the playlist



72
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 72

optional :owner, -> { Spotted::Models::PlaylistRetrieveResponse::Owner }

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


82
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 82

optional :published, Spotted::Internal::Type::Boolean

#snapshot_id ⇒ String?

The version identifier for the current playlist. Can be supplied in other requests to target a specific playlist version

Returns:

  • (String, nil)


89
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 89

optional :snapshot_id, String

#tracks ⇒ Spotted::Models::PlaylistRetrieveResponse::Tracks?

Deprecated.

Deprecated: Use items instead. The tracks of the playlist.



97
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 97

optional :tracks, -> { Spotted::Models::PlaylistRetrieveResponse::Tracks }

#type ⇒ String?

The object type: "playlist"

Returns:

  • (String, nil)


103
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 103

optional :type, String

#uri ⇒ String?

The Spotify URI for the playlist.

Returns:

  • (String, nil)


110
# File 'lib/spotted/models/playlist_retrieve_response.rb', line 110

optional :uri, String