Class: Spotted::Models::PlaylistUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::PlaylistUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/spotted/models/playlist_update_params.rb
Overview
Instance Attribute Summary collapse
-
#collaborative ⇒ Boolean?
If
true, the playlist will become collaborative and other users will be able to modify the playlist in their Spotify client. -
#description ⇒ String?
Value for playlist description as displayed in Spotify Clients and in the Web API.
-
#name ⇒ String?
The new name for the playlist, for example
"My New Playlist Title". -
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's profile or not):
truethe playlist will be public,falsethe playlist will be private,nullthe playlist status is not relevant.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(collaborative: nil, description: nil, name: nil, published: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PlaylistUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(collaborative: nil, description: nil, name: nil, published: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Spotted::Models::PlaylistUpdateParams for more details.
|
|
# File 'lib/spotted/models/playlist_update_params.rb', line 41
|
Instance Attribute Details
#collaborative ⇒ Boolean?
If true, the playlist will become collaborative and other users will be able
to modify the playlist in their Spotify client.
Note: You can only
set collaborative to true on non-public playlists.
16 |
# File 'lib/spotted/models/playlist_update_params.rb', line 16 optional :collaborative, Spotted::Internal::Type::Boolean |
#description ⇒ String?
Value for playlist description as displayed in Spotify Clients and in the Web API.
23 |
# File 'lib/spotted/models/playlist_update_params.rb', line 23 optional :description, String |
#name ⇒ String?
The new name for the playlist, for example "My New Playlist Title"
29 |
# File 'lib/spotted/models/playlist_update_params.rb', line 29 optional :name, String |
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's
profile or not): true the playlist will be public, false the playlist will
be private, null the playlist status is not relevant. For more about
public/private status, see
Working with Playlists
39 |
# File 'lib/spotted/models/playlist_update_params.rb', line 39 optional :published, Spotted::Internal::Type::Boolean |