Class: Spotted::Models::PlaylistUserObject

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/playlist_user_object.rb

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, external_urls: nil, href: nil, published: nil, type: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::PlaylistUserObject for more details.

Parameters:

  • id (String) (defaults to: nil) —

    The Spotify user ID for this

  • external_urls (Spotted::Models::ExternalURLObject) (defaults to: nil) —

    Known public external URLs for this user.

  • href (String) (defaults to: nil) —

    A link to the Web API endpoint for this user.

  • published (Boolean) (defaults to: nil) —

    The playlist's public/private status (if it should be added to the user's profil

  • type (Symbol, Spotted::Models::PlaylistUserObject::Type) (defaults to: nil) —

    The object type.

  • uri (String) (defaults to: nil) —

    The Spotify URI for this use



# File 'lib/spotted/models/playlist_user_object.rb', line 48

Instance Attribute Details

#external_urls ⇒ Spotted::Models::ExternalURLObject?

Known public external URLs for this user.



17
# File 'lib/spotted/models/playlist_user_object.rb', line 17

optional :external_urls, -> { Spotted::ExternalURLObject }

#href ⇒ String?

A link to the Web API endpoint for this user.

Returns:

  • (String, nil)


23
# File 'lib/spotted/models/playlist_user_object.rb', line 23

optional :href, String

#id ⇒ String?

The Spotify user ID for this user.

Returns:

  • (String, nil)


11
# File 'lib/spotted/models/playlist_user_object.rb', line 11

optional :id, String

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


33
# File 'lib/spotted/models/playlist_user_object.rb', line 33

optional :published, Spotted::Internal::Type::Boolean

#type ⇒ Symbol, ...

The object type.



39
# File 'lib/spotted/models/playlist_user_object.rb', line 39

optional :type, enum: -> { Spotted::PlaylistUserObject::Type }

#uri ⇒ String?

The Spotify URI for this user.

Returns:

  • (String, nil)


46
# File 'lib/spotted/models/playlist_user_object.rb', line 46

optional :uri, String