Class: Spotted::Models::Playlists::TrackAddParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::Playlists::TrackAddParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/spotted/models/playlists/track_add_params.rb
Overview
Instance Attribute Summary collapse
-
#position ⇒ Integer?
The position to insert the items, a zero-based index.
-
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's profile or not):
truethe playlist will be public,falsethe playlist will be private,nullthe playlist status is not relevant. -
#uris ⇒ Array<String>?
A JSON array of the Spotify URIs to add.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(position: nil, published: nil, uris: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TrackAddParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(position: nil, published: nil, uris: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Spotted::Models::Playlists::TrackAddParams for more details.
|
|
# File 'lib/spotted/models/playlists/track_add_params.rb', line 43
|
Instance Attribute Details
#position ⇒ Integer?
The position to insert the items, a zero-based index. For example, to insert the
items in the first position: position=0 ; to insert the items in the third
position: position=2. If omitted, the items will be appended to the playlist.
Items are added in the order they appear in the uris array. For example:
{"uris": ["spotify:track:4iV5W9uYEdYUVa79Axb7Rh","spotify:track:1301WleyT98MSxVHPZCA6M"], "position": 3}
19 |
# File 'lib/spotted/models/playlists/track_add_params.rb', line 19 optional :position, Integer |
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's
profile or not): true the playlist will be public, false the playlist will
be private, null the playlist status is not relevant. For more about
public/private status, see
Working with Playlists
29 |
# File 'lib/spotted/models/playlists/track_add_params.rb', line 29 optional :published, Spotted::Internal::Type::Boolean |
#uris ⇒ Array<String>?
A JSON array of the
Spotify URIs to add. For
example:
{"uris": ["spotify:track:4iV5W9uYEdYUVa79Axb7Rh","spotify:track:1301WleyT98MSxVHPZCA6M", "spotify:episode:512ojhOuo1ktJprKbVcKyQ"]}<br/>A
maximum of 100 items can be added in one request. Note: if the uris
parameter is present in the query string, any URIs listed here in the body will
be ignored.
41 |
# File 'lib/spotted/models/playlists/track_add_params.rb', line 41 optional :uris, Spotted::Internal::Type::ArrayOf[String] |