Class: Spotted::Models::Playlists::TrackListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/spotted/models/playlists/track_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(additional_types: nil, fields: nil, limit: nil, market: nil, offset: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::Playlists::TrackListParams for more details.

Parameters:

  • additional_types (String) (defaults to: nil) —

    A comma-separated list of item types that your client supports besides the defau

  • fields (String) (defaults to: nil) —

    Filters for the query: a comma-separated list of the

  • limit (Integer) (defaults to: nil) —

    The maximum number of items to return. Default: 20. Minimum: 1. Maximum: 100.

  • market (String) (defaults to: nil) —

    An [ISO 3166-1 alpha-2 country code](https://en.wikipedia.org/wiki/ISO_3166-1_al

  • offset (Integer) (defaults to: nil) —

    The index of the first item to return. Default: 0 (the first item). Use with lim

  • request_options (Spotted::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/spotted/models/playlists/track_list_params.rb', line 64

Instance Attribute Details

#additional_types ⇒ String?

A comma-separated list of item types that your client supports besides the default track type. Valid types are: track and episode.
_Note: This parameter was introduced to allow existing clients to maintain their current behaviour and might be deprecated in the future._
In addition to providing this parameter, make sure that your client properly handles cases of new types in the future by checking against the type field of each object.

Returns:

  • (String, nil)


20
# File 'lib/spotted/models/playlists/track_list_params.rb', line 20

optional :additional_types, String

#fields ⇒ String?

Filters for the query: a comma-separated list of the fields to return. If omitted, all fields are returned. For example, to get just the total number of items and the request limit:
fields=total,limit<br/>A dot separator can be used to specify non-reoccurring fields, while parentheses can be used to specify reoccurring fields within objects. For example, to get just the added date and user ID of the adder:
fields=items(added_at,added_by.id)<br/>Use multiple parentheses to drill down into nested objects, for example:
fields=items(track(name,href,album(name,href)))<br/>Fields can be excluded by prefixing them with an exclamation mark, for example:
fields=items.track.album(!external_urls,images)

Returns:

  • (String, nil)


35
# File 'lib/spotted/models/playlists/track_list_params.rb', line 35

optional :fields, String

#limit ⇒ Integer?

The maximum number of items to return. Default: 20. Minimum: 1. Maximum: 100.

Returns:

  • (Integer, nil)


41
# File 'lib/spotted/models/playlists/track_list_params.rb', line 41

optional :limit, Integer

#market ⇒ String?

An ISO 3166-1 alpha-2 country code. If a country code is specified, only content that is available in that market will be returned.
If a valid user access token is specified in the request header, the country associated with the user account will take priority over this parameter.
_Note: If neither market or user country are provided, the content is considered unavailable for the client._
Users can view the country that is associated with their account in the account settings.

Returns:

  • (String, nil)


55
# File 'lib/spotted/models/playlists/track_list_params.rb', line 55

optional :market, String

#offset ⇒ Integer?

The index of the first item to return. Default: 0 (the first item). Use with limit to get the next set of items.

Returns:

  • (Integer, nil)


62
# File 'lib/spotted/models/playlists/track_list_params.rb', line 62

optional :offset, Integer