Class: Spotted::Models::Playlists::TrackRemoveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::Playlists::TrackRemoveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/spotted/models/playlists/track_remove_params.rb
Overview
Defined Under Namespace
Classes: Track
Instance Attribute Summary collapse
-
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's profile or not):
truethe playlist will be public,falsethe playlist will be private,nullthe playlist status is not relevant. -
#snapshot_id ⇒ String?
The playlist's snapshot ID against which you want to make the changes.
-
#tracks ⇒ Array<Spotted::Models::Playlists::TrackRemoveParams::Track>
An array of objects containing Spotify URIs of the tracks or episodes to remove.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Spotted::Internal::Type::BaseModel
Instance Attribute Details
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's
profile or not): true the playlist will be public, false the playlist will
be private, null the playlist status is not relevant. For more about
public/private status, see
Working with Playlists
29 |
# File 'lib/spotted/models/playlists/track_remove_params.rb', line 29 optional :published, Spotted::Internal::Type::Boolean |
#snapshot_id ⇒ String?
The playlist's snapshot ID against which you want to make the changes. The API will validate that the specified items exist and in the specified positions and make the changes, even if more recent changes have been made to the playlist.
37 |
# File 'lib/spotted/models/playlists/track_remove_params.rb', line 37 optional :snapshot_id, String |
#tracks ⇒ Array<Spotted::Models::Playlists::TrackRemoveParams::Track>
An array of objects containing
Spotify URIs of the tracks
or episodes to remove. For example:
{ "tracks": [{ "uri": "spotify:track:4iV5W9uYEdYUVa79Axb7Rh" },{ "uri": "spotify:track:1301WleyT98MSxVHPZCA6M" }] }.
A maximum of 100 objects can be sent at once.
19 |
# File 'lib/spotted/models/playlists/track_remove_params.rb', line 19 required :tracks, -> { Spotted::Internal::Type::ArrayOf[Spotted::Playlists::TrackRemoveParams::Track] } |