Class: Spotted::Models::RecommendationGetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::RecommendationGetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/spotted/models/recommendation_get_params.rb
Overview
Instance Attribute Summary collapse
-
#limit ⇒ Integer?
The target size of the list of recommended tracks.
- #market ⇒ String?
-
#max_acousticness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_danceability ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_duration_ms ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_energy ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_instrumentalness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_key ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_liveness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_loudness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_mode ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_popularity ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_speechiness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_tempo ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_time_signature ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#max_valence ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track attribute’s value can be provided.
-
#min_acousticness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_danceability ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_duration_ms ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_energy ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_instrumentalness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_key ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_liveness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_loudness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_mode ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_popularity ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_speechiness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_tempo ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_time_signature ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#min_valence ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s value can be provided.
-
#seed_artists ⇒ String?
A comma separated list of Spotify IDs for seed artists.
-
#seed_genres ⇒ String?
A comma separated list of any genres in the set of available genre seeds.
-
#seed_tracks ⇒ String?
A comma separated list of Spotify IDs for a seed track.
-
#target_acousticness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_danceability ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_duration_ms ⇒ Integer?
Target duration of the track (ms).
-
#target_energy ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_instrumentalness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_key ⇒ Integer?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_liveness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_loudness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_mode ⇒ Integer?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_popularity ⇒ Integer?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_speechiness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_tempo ⇒ Float?
Target tempo (BPM).
-
#target_time_signature ⇒ Integer?
For each of the tunable track attributes (below) a target value may be provided.
-
#target_valence ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(limit: nil, market: nil, max_acousticness: nil, max_danceability: nil, max_duration_ms: nil, max_energy: nil, max_instrumentalness: nil, max_key: nil, max_liveness: nil, max_loudness: nil, max_mode: nil, max_popularity: nil, max_speechiness: nil, max_tempo: nil, max_time_signature: nil, max_valence: nil, min_acousticness: nil, min_danceability: nil, min_duration_ms: nil, min_energy: nil, min_instrumentalness: nil, min_key: nil, min_liveness: nil, min_loudness: nil, min_mode: nil, min_popularity: nil, min_speechiness: nil, min_tempo: nil, min_time_signature: nil, min_valence: nil, seed_artists: nil, seed_genres: nil, seed_tracks: nil, target_acousticness: nil, target_danceability: nil, target_duration_ms: nil, target_energy: nil, target_instrumentalness: nil, target_key: nil, target_liveness: nil, target_loudness: nil, target_mode: nil, target_popularity: nil, target_speechiness: nil, target_tempo: nil, target_time_signature: nil, target_valence: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see RecommendationGetParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(limit: nil, market: nil, max_acousticness: nil, max_danceability: nil, max_duration_ms: nil, max_energy: nil, max_instrumentalness: nil, max_key: nil, max_liveness: nil, max_loudness: nil, max_mode: nil, max_popularity: nil, max_speechiness: nil, max_tempo: nil, max_time_signature: nil, max_valence: nil, min_acousticness: nil, min_danceability: nil, min_duration_ms: nil, min_energy: nil, min_instrumentalness: nil, min_key: nil, min_liveness: nil, min_loudness: nil, min_mode: nil, min_popularity: nil, min_speechiness: nil, min_tempo: nil, min_time_signature: nil, min_valence: nil, seed_artists: nil, seed_genres: nil, seed_tracks: nil, target_acousticness: nil, target_danceability: nil, target_duration_ms: nil, target_energy: nil, target_instrumentalness: nil, target_key: nil, target_liveness: nil, target_loudness: nil, target_mode: nil, target_popularity: nil, target_speechiness: nil, target_tempo: nil, target_time_signature: nil, target_valence: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Spotted::Models::RecommendationGetParams for more details.
|
|
# File 'lib/spotted/models/recommendation_get_params.rb', line 448
|
Instance Attribute Details
#limit ⇒ Integer?
The target size of the list of recommended tracks. For seeds with unusually small pools or when highly restrictive filtering is applied, it may be impossible to generate the requested number of recommended tracks. Debugging information for such cases is available in the response. Default: 20. Minimum: 1. Maximum: 100.
18 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 18 optional :limit, Integer |
#market ⇒ String?
An
ISO 3166-1 alpha-2 country code.
If a country code is specified, only content that is available in that market
will be returned.
If a valid user access token is specified in the request
header, the country associated with the user account will take priority over
this parameter.
_Note: If neither market or user country are provided,
the content is considered unavailable for the client._
Users can view the
country that is associated with their account in the
account settings.
32 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 32 optional :market, String |
#max_acousticness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
41 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 41 optional :max_acousticness, Float |
#max_danceability ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
50 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 50 optional :max_danceability, Float |
#max_duration_ms ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
59 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 59 optional :max_duration_ms, Integer |
#max_energy ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
68 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 68 optional :max_energy, Float |
#max_instrumentalness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
77 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 77 optional :max_instrumentalness, Float |
#max_key ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
86 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 86 optional :max_key, Integer |
#max_liveness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
95 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 95 optional :max_liveness, Float |
#max_loudness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
104 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 104 optional :max_loudness, Float |
#max_mode ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
113 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 113 optional :max_mode, Integer |
#max_popularity ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
122 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 122 optional :max_popularity, Integer |
#max_speechiness ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
131 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 131 optional :max_speechiness, Float |
#max_tempo ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
140 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 140 optional :max_tempo, Float |
#max_time_signature ⇒ Integer?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
149 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 149 optional :max_time_signature, Integer |
#max_valence ⇒ Float?
For each tunable track attribute, a hard ceiling on the selected track
attribute’s value can be provided. See tunable track attributes below for the
list of available options. For example, max_instrumentalness=0.35 would filter
out most tracks that are likely to be instrumental.
158 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 158 optional :max_valence, Float |
#min_acousticness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
167 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 167 optional :min_acousticness, Float |
#min_danceability ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
176 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 176 optional :min_danceability, Float |
#min_duration_ms ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
185 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 185 optional :min_duration_ms, Integer |
#min_energy ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
194 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 194 optional :min_energy, Float |
#min_instrumentalness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
203 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 203 optional :min_instrumentalness, Float |
#min_key ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
212 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 212 optional :min_key, Integer |
#min_liveness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
221 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 221 optional :min_liveness, Float |
#min_loudness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
230 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 230 optional :min_loudness, Float |
#min_mode ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
239 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 239 optional :min_mode, Integer |
#min_popularity ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
248 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 248 optional :min_popularity, Integer |
#min_speechiness ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
257 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 257 optional :min_speechiness, Float |
#min_tempo ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
266 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 266 optional :min_tempo, Float |
#min_time_signature ⇒ Integer?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
275 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 275 optional :min_time_signature, Integer |
#min_valence ⇒ Float?
For each tunable track attribute, a hard floor on the selected track attribute’s
value can be provided. See tunable track attributes below for the list of
available options. For example, min_tempo=140 would restrict results to only
those tracks with a tempo of greater than 140 beats per minute.
284 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 284 optional :min_valence, Float |
#seed_artists ⇒ String?
A comma separated list of
Spotify IDs for seed
artists. Up to 5 seed values may be provided in any combination of
seed_artists, seed_tracks and seed_genres.
Note: only required
if seed_genres and seed_tracks are not set.
294 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 294 optional :seed_artists, String |
#seed_genres ⇒ String?
A comma separated list of any genres in the set of
available genre seeds.
Up to 5 seed values may be provided in any combination of seed_artists,
seed_tracks and seed_genres.
Note: only required if seed_artists
and seed_tracks are not set.
304 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 304 optional :seed_genres, String |
#seed_tracks ⇒ String?
A comma separated list of
Spotify IDs for a seed
track. Up to 5 seed values may be provided in any combination of seed_artists,
seed_tracks and seed_genres.
Note: only required if seed_artists
and seed_genres are not set.
314 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 314 optional :seed_tracks, String |
#target_acousticness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
324 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 324 optional :target_acousticness, Float |
#target_danceability ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
334 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 334 optional :target_danceability, Float |
#target_duration_ms ⇒ Integer?
Target duration of the track (ms)
340 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 340 optional :target_duration_ms, Integer |
#target_energy ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
350 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 350 optional :target_energy, Float |
#target_instrumentalness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
360 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 360 optional :target_instrumentalness, Float |
#target_key ⇒ Integer?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
370 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 370 optional :target_key, Integer |
#target_liveness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
380 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 380 optional :target_liveness, Float |
#target_loudness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
390 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 390 optional :target_loudness, Float |
#target_mode ⇒ Integer?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
400 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 400 optional :target_mode, Integer |
#target_popularity ⇒ Integer?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
410 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 410 optional :target_popularity, Integer |
#target_speechiness ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
420 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 420 optional :target_speechiness, Float |
#target_tempo ⇒ Float?
Target tempo (BPM)
426 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 426 optional :target_tempo, Float |
#target_time_signature ⇒ Integer?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
436 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 436 optional :target_time_signature, Integer |
#target_valence ⇒ Float?
For each of the tunable track attributes (below) a target value may be provided.
Tracks with the attribute values nearest to the target values will be preferred.
For example, you might request target_energy=0.6 and
target_danceability=0.8. All target values will be weighed equally in ranking
results.
446 |
# File 'lib/spotted/models/recommendation_get_params.rb', line 446 optional :target_valence, Float |