Class: Spotted::Models::RecommendationGetResponse::Seed

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/recommendation_get_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, after_filtering_size: nil, after_relinking_size: nil, href: nil, initial_pool_size: nil, published: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::RecommendationGetResponse::Seed for more details.

Parameters:

  • id (String) (defaults to: nil) —

    The id used to select this seed. This will be the same as the string used in the

  • after_filtering_size (Integer) (defaults to: nil) —

    The number of tracks available after min_* and max_* filters have been appli

  • after_relinking_size (Integer) (defaults to: nil) —

    The number of tracks available after relinking for regional availability.

  • href (String) (defaults to: nil) —

    A link to the full track or artist data for this seed. For tracks this will be a

  • initial_pool_size (Integer) (defaults to: nil) —

    The number of recommended tracks available for this seed.

  • published (Boolean) (defaults to: nil) —

    The playlist's public/private status (if it should be added to the user's profil

  • type (String) (defaults to: nil) —

    The entity type of this seed. One of artist, track or genre.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/spotted/models/recommendation_get_response.rb', line 39

class Seed < Spotted::Internal::Type::BaseModel
  # @!attribute id
  #   The id used to select this seed. This will be the same as the string used in the
  #   `seed_artists`, `seed_tracks` or `seed_genres` parameter.
  #
  #   @return [String, nil]
  optional :id, String

  # @!attribute after_filtering_size
  #   The number of tracks available after min\_\* and max\_\* filters have been
  #   applied.
  #
  #   @return [Integer, nil]
  optional :after_filtering_size, Integer, api_name: :afterFilteringSize

  # @!attribute after_relinking_size
  #   The number of tracks available after relinking for regional availability.
  #
  #   @return [Integer, nil]
  optional :after_relinking_size, Integer, api_name: :afterRelinkingSize

  # @!attribute href
  #   A link to the full track or artist data for this seed. For tracks this will be a
  #   link to a Track Object. For artists a link to an Artist Object. For genre seeds,
  #   this value will be `null`.
  #
  #   @return [String, nil]
  optional :href, String

  # @!attribute initial_pool_size
  #   The number of recommended tracks available for this seed.
  #
  #   @return [Integer, nil]
  optional :initial_pool_size, Integer, api_name: :initialPoolSize

  # @!attribute published
  #   The playlist's public/private status (if it should be added to the user's
  #   profile or not): `true` the playlist will be public, `false` the playlist will
  #   be private, `null` the playlist status is not relevant. For more about
  #   public/private status, see
  #   [Working with Playlists](/documentation/web-api/concepts/playlists)
  #
  #   @return [Boolean, nil]
  optional :published, Spotted::Internal::Type::Boolean

  # @!attribute type
  #   The entity type of this seed. One of `artist`, `track` or `genre`.
  #
  #   @return [String, nil]
  optional :type, String

  # @!method initialize(id: nil, after_filtering_size: nil, after_relinking_size: nil, href: nil, initial_pool_size: nil, published: nil, type: nil)
  #   Some parameter documentations has been truncated, see
  #   {Spotted::Models::RecommendationGetResponse::Seed} for more details.
  #
  #   @param id [String] The id used to select this seed. This will be the same as the string used in the
  #
  #   @param after_filtering_size [Integer] The number of tracks available after min\_\* and max\_\* filters have been appli
  #
  #   @param after_relinking_size [Integer] The number of tracks available after relinking for regional availability.
  #
  #   @param href [String] A link to the full track or artist data for this seed. For tracks this will be a
  #
  #   @param initial_pool_size [Integer] The number of recommended tracks available for this seed.
  #
  #   @param published [Boolean] The playlist's public/private status (if it should be added to the user's profil
  #
  #   @param type [String] The entity type of this seed. One of `artist`, `track` or `genre`.
end

Instance Attribute Details

#after_filtering_size ⇒ Integer?

The number of tracks available after min_* and max_* filters have been applied.

Returns:

  • (Integer, nil)


52
# File 'lib/spotted/models/recommendation_get_response.rb', line 52

optional :after_filtering_size, Integer, api_name: :afterFilteringSize

#after_relinking_size ⇒ Integer?

The number of tracks available after relinking for regional availability.

Returns:

  • (Integer, nil)


58
# File 'lib/spotted/models/recommendation_get_response.rb', line 58

optional :after_relinking_size, Integer, api_name: :afterRelinkingSize

#href ⇒ String?

A link to the full track or artist data for this seed. For tracks this will be a link to a Track Object. For artists a link to an Artist Object. For genre seeds, this value will be null.

Returns:

  • (String, nil)


66
# File 'lib/spotted/models/recommendation_get_response.rb', line 66

optional :href, String

#id ⇒ String?

The id used to select this seed. This will be the same as the string used in the seed_artists, seed_tracks or seed_genres parameter.

Returns:

  • (String, nil)


45
# File 'lib/spotted/models/recommendation_get_response.rb', line 45

optional :id, String

#initial_pool_size ⇒ Integer?

The number of recommended tracks available for this seed.

Returns:

  • (Integer, nil)


72
# File 'lib/spotted/models/recommendation_get_response.rb', line 72

optional :initial_pool_size, Integer, api_name: :initialPoolSize

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


82
# File 'lib/spotted/models/recommendation_get_response.rb', line 82

optional :published, Spotted::Internal::Type::Boolean

#type ⇒ String?

The entity type of this seed. One of artist, track or genre.

Returns:

  • (String, nil)


88
# File 'lib/spotted/models/recommendation_get_response.rb', line 88

optional :type, String