Module: Spotted::Models::SearchQueryParams::IncludeExternal
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/spotted/models/search_query_params.rb
Overview
If include_external=audio is specified it signals that the client can play
externally hosted audio content, and marks the content as playable in the
response. By default externally hosted audio content is marked as unplayable in
the response.
Constant Summary collapse
- AUDIO =
:audio
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/spotted/models/search_query_params.rb', line 115
|