Class: Spotted::Models::ShowBase

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/show_base.rb

Direct Known Subclasses

ShowRetrieveResponse

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, available_markets:, copyrights:, description:, explicit:, external_urls:, href:, html_description:, images:, is_externally_hosted:, languages:, media_type:, name:, publisher:, total_episodes:, uri:, published: nil, type: :show) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::ShowBase for more details.

Parameters:

  • id (String) —

    The Spotify ID for the show.

  • available_markets (Array<String>) —

    A list of the countries in which the show can be played, identified by their [IS

  • copyrights (Array<Spotted::Models::CopyrightObject>) —

    The copyright statements of the show.

  • description (String) —

    A description of the show. HTML tags are stripped away from this field, use `htm

  • explicit (Boolean) —

    Whether or not the show has explicit content (true = yes it does; false = no it

  • external_urls (Spotted::Models::ExternalURLObject) —

    External URLs for this show.

  • href (String) —

    A link to the Web API endpoint providing full details of the show.

  • html_description (String) —

    A description of the show. This field may contain HTML tags.

  • images (Array<Spotted::Models::ImageObject>) —

    The cover art for the show in various sizes, widest first.

  • is_externally_hosted (Boolean) —

    True if all of the shows episodes are hosted outside of Spotify's CDN. This fiel

  • languages (Array<String>) —

    A list of the languages used in the show, identified by their [ISO 639](https://

  • media_type (String) —

    The media type of the show.

  • name (String) —

    The name of the episode.

  • publisher (String) —

    The publisher of the show.

  • total_episodes (Integer) —

    The total number of episodes in the show.

  • uri (String) —

    The Spotify URI for the show

  • published (Boolean) (defaults to: nil) —

    The playlist's public/private status (if it should be added to the user's profil

  • type (Symbol, :show) (defaults to: :show) —

    The object type.



# File 'lib/spotted/models/show_base.rb', line 128

Instance Attribute Details

#available_markets ⇒ Array<String>

Deprecated.

A list of the countries in which the show can be played, identified by their ISO 3166-1 alpha-2 code.

Returns:

  • (Array<String>)


19
# File 'lib/spotted/models/show_base.rb', line 19

required :available_markets, Spotted::Internal::Type::ArrayOf[String]

#copyrights ⇒ Array<Spotted::Models::CopyrightObject>

The copyright statements of the show.



25
# File 'lib/spotted/models/show_base.rb', line 25

required :copyrights, -> { Spotted::Internal::Type::ArrayOf[Spotted::CopyrightObject] }

#description ⇒ String

A description of the show. HTML tags are stripped away from this field, use html_description field in case HTML tags are needed.

Returns:

  • (String)


32
# File 'lib/spotted/models/show_base.rb', line 32

required :description, String

#explicit ⇒ Boolean

Whether or not the show has explicit content (true = yes it does; false = no it does not OR unknown).

Returns:

  • (Boolean)


39
# File 'lib/spotted/models/show_base.rb', line 39

required :explicit, Spotted::Internal::Type::Boolean

#external_urls ⇒ Spotted::Models::ExternalURLObject

External URLs for this show.



45
# File 'lib/spotted/models/show_base.rb', line 45

required :external_urls, -> { Spotted::ExternalURLObject }

#href ⇒ String

A link to the Web API endpoint providing full details of the show.

Returns:

  • (String)


51
# File 'lib/spotted/models/show_base.rb', line 51

required :href, String

#html_description ⇒ String

A description of the show. This field may contain HTML tags.

Returns:

  • (String)


57
# File 'lib/spotted/models/show_base.rb', line 57

required :html_description, String

#id ⇒ String

The Spotify ID for the show.

Returns:

  • (String)


10
# File 'lib/spotted/models/show_base.rb', line 10

required :id, String

#images ⇒ Array<Spotted::Models::ImageObject>

The cover art for the show in various sizes, widest first.

Returns:



63
# File 'lib/spotted/models/show_base.rb', line 63

required :images, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] }

#is_externally_hosted ⇒ Boolean

True if all of the shows episodes are hosted outside of Spotify's CDN. This field might be null in some cases.

Returns:

  • (Boolean)


70
# File 'lib/spotted/models/show_base.rb', line 70

required :is_externally_hosted, Spotted::Internal::Type::Boolean

#languages ⇒ Array<String>

A list of the languages used in the show, identified by their ISO 639 code.

Returns:

  • (Array<String>)


77
# File 'lib/spotted/models/show_base.rb', line 77

required :languages, Spotted::Internal::Type::ArrayOf[String]

#media_type ⇒ String

The media type of the show.

Returns:

  • (String)


83
# File 'lib/spotted/models/show_base.rb', line 83

required :media_type, String

#name ⇒ String

The name of the episode.

Returns:

  • (String)


89
# File 'lib/spotted/models/show_base.rb', line 89

required :name, String

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


126
# File 'lib/spotted/models/show_base.rb', line 126

optional :published, Spotted::Internal::Type::Boolean

#publisher ⇒ String

Deprecated.

The publisher of the show.

Returns:

  • (String)


97
# File 'lib/spotted/models/show_base.rb', line 97

required :publisher, String

#total_episodes ⇒ Integer

The total number of episodes in the show.

Returns:

  • (Integer)


103
# File 'lib/spotted/models/show_base.rb', line 103

required :total_episodes, Integer

#type ⇒ Symbol, :show

The object type.

Returns:

  • (Symbol, :show)


109
# File 'lib/spotted/models/show_base.rb', line 109

required :type, const: :show

#uri ⇒ String

The Spotify URI for the show.

Returns:

  • (String)


116
# File 'lib/spotted/models/show_base.rb', line 116

required :uri, String