Class: Spotted::Models::SimplifiedPlaylistObject

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/simplified_playlist_object.rb

Defined Under Namespace

Classes: Owner

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, collaborative: nil, description: nil, external_urls: nil, href: nil, images: nil, items: nil, name: nil, owner: nil, published: nil, snapshot_id: nil, tracks: nil, type: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::SimplifiedPlaylistObject for more details.

other

Parameters:

  • id (String) (defaults to: nil) —

    The Spotify ID for the playl

  • collaborative (Boolean) (defaults to: nil) —

    true if the owner allows other users to modify the playlist.

  • description (String) (defaults to: nil) —

    The playlist description. _Only returned for modified, verified playlists,

  • external_urls (Spotted::Models::ExternalURLObject) (defaults to: nil) —

    Known external URLs for this playlist.

  • href (String) (defaults to: nil) —

    A link to the Web API endpoint providing full details of the playlist.

  • images (Array<Spotted::Models::ImageObject>) (defaults to: nil) —

    Images for the playlist. The array may be empty or contain up to three images. T

  • items (Spotted::Models::PlaylistTracksRefObject) (defaults to: nil) —

    A collection containing a link ( href ) to the Web API endpoint where full det

  • name (String) (defaults to: nil) —

    The name of the playlist.

  • owner (Spotted::Models::SimplifiedPlaylistObject::Owner) (defaults to: nil) —

    The user who owns the playlist

  • published (Boolean) (defaults to: nil) —

    The playlist's public/private status (if it should be added to the user's profil

  • snapshot_id (String) (defaults to: nil) —

    The version identifier for the current playlist. Can be supplied in other reques

  • tracks (Spotted::Models::PlaylistTracksRefObject) (defaults to: nil) —

    Deprecated: Use items instead. A collection containing a link ( href ) t

  • type (String) (defaults to: nil) —

    The object type: "playlist"

  • uri (String) (defaults to: nil) —

    The Spotify URI for the play



# File 'lib/spotted/models/simplified_playlist_object.rb', line 110

Instance Attribute Details

#collaborative ⇒ Boolean?

true if the owner allows other users to modify the playlist.

Returns:

  • (Boolean, nil)


17
# File 'lib/spotted/models/simplified_playlist_object.rb', line 17

optional :collaborative, Spotted::Internal::Type::Boolean

#description ⇒ String?

The playlist description. Only returned for modified, verified playlists, otherwise null.

Returns:

  • (String, nil)


24
# File 'lib/spotted/models/simplified_playlist_object.rb', line 24

optional :description, String

#external_urls ⇒ Spotted::Models::ExternalURLObject?

Known external URLs for this playlist.



30
# File 'lib/spotted/models/simplified_playlist_object.rb', line 30

optional :external_urls, -> { Spotted::ExternalURLObject }

#href ⇒ String?

A link to the Web API endpoint providing full details of the playlist.

Returns:

  • (String, nil)


36
# File 'lib/spotted/models/simplified_playlist_object.rb', line 36

optional :href, String

#id ⇒ String?

The Spotify ID for the playlist.

Returns:

  • (String, nil)


11
# File 'lib/spotted/models/simplified_playlist_object.rb', line 11

optional :id, String

#images ⇒ Array<Spotted::Models::ImageObject>?

Images for the playlist. The array may be empty or contain up to three images. The images are returned by size in descending order. See Working with Playlists. Note: If returned, the source URL for the image (url) is temporary and will expire in less than a day.

Returns:



46
# File 'lib/spotted/models/simplified_playlist_object.rb', line 46

optional :images, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] }

#items ⇒ Spotted::Models::PlaylistTracksRefObject?

A collection containing a link ( href ) to the Web API endpoint where full details of the playlist's items can be retrieved, along with the total number of items in the playlist. Note, a track object may be null. This can happen if a track is no longer available.



55
# File 'lib/spotted/models/simplified_playlist_object.rb', line 55

optional :items, -> { Spotted::PlaylistTracksRefObject }

#name ⇒ String?

The name of the playlist.

Returns:

  • (String, nil)


61
# File 'lib/spotted/models/simplified_playlist_object.rb', line 61

optional :name, String

#owner ⇒ Spotted::Models::SimplifiedPlaylistObject::Owner?

The user who owns the playlist



67
# File 'lib/spotted/models/simplified_playlist_object.rb', line 67

optional :owner, -> { Spotted::SimplifiedPlaylistObject::Owner }

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


77
# File 'lib/spotted/models/simplified_playlist_object.rb', line 77

optional :published, Spotted::Internal::Type::Boolean

#snapshot_id ⇒ String?

The version identifier for the current playlist. Can be supplied in other requests to target a specific playlist version

Returns:

  • (String, nil)


84
# File 'lib/spotted/models/simplified_playlist_object.rb', line 84

optional :snapshot_id, String

#tracks ⇒ Spotted::Models::PlaylistTracksRefObject?

Deprecated.

Deprecated: Use items instead. A collection containing a link ( href ) to the Web API endpoint where full details of the playlist's tracks can be retrieved, along with the total number of tracks in the playlist. Note, a track object may be null. This can happen if a track is no longer available.



95
# File 'lib/spotted/models/simplified_playlist_object.rb', line 95

optional :tracks, -> { Spotted::PlaylistTracksRefObject }

#type ⇒ String?

The object type: "playlist"

Returns:

  • (String, nil)


101
# File 'lib/spotted/models/simplified_playlist_object.rb', line 101

optional :type, String

#uri ⇒ String?

The Spotify URI for the playlist.

Returns:

  • (String, nil)


108
# File 'lib/spotted/models/simplified_playlist_object.rb', line 108

optional :uri, String