Class: Spotted::Models::UserRetrieveProfileResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/user_retrieve_profile_response.rb

Overview

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, display_name: nil, external_urls: nil, followers: nil, href: nil, images: nil, published: nil, type: nil, uri: nil) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::UserRetrieveProfileResponse for more details.

Parameters:

  • id (String) (defaults to: nil) —

    The Spotify user ID for this

  • display_name (String, nil) (defaults to: nil) —

    The name displayed on the user's profile. null if not available.

  • external_urls (Spotted::Models::ExternalURLObject) (defaults to: nil) —

    Known public external URLs for this user.

  • followers (Spotted::Models::FollowersObject) (defaults to: nil) —

    Information about the followers of this user.

  • href (String) (defaults to: nil) —

    A link to the Web API endpoint for this user.

  • images (Array<Spotted::Models::ImageObject>) (defaults to: nil) —

    The user's profile image.

  • published (Boolean) (defaults to: nil) —

    The playlist's public/private status (if it should be added to the user's profil

  • type (Symbol, Spotted::Models::UserRetrieveProfileResponse::Type) (defaults to: nil) —

    The object type.

  • uri (String) (defaults to: nil) —

    The Spotify URI for this use



# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 69

Instance Attribute Details

#display_name ⇒ String?

The name displayed on the user's profile. null if not available.

Returns:

  • (String, nil)


18
# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 18

optional :display_name, String, nil?: true

#external_urls ⇒ Spotted::Models::ExternalURLObject?

Known public external URLs for this user.



24
# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 24

optional :external_urls, -> { Spotted::ExternalURLObject }

#followers ⇒ Spotted::Models::FollowersObject?

Deprecated.

Information about the followers of this user.



32
# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 32

optional :followers, -> { Spotted::FollowersObject }

#href ⇒ String?

A link to the Web API endpoint for this user.

Returns:

  • (String, nil)


38
# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 38

optional :href, String

#id ⇒ String?

The Spotify user ID for this user.

Returns:

  • (String, nil)


12
# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 12

optional :id, String

#images ⇒ Array<Spotted::Models::ImageObject>?

The user's profile image.

Returns:



44
# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 44

optional :images, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] }

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


54
# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 54

optional :published, Spotted::Internal::Type::Boolean

#type ⇒ Symbol, ...

The object type.



60
# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 60

optional :type, enum: -> { Spotted::Models::UserRetrieveProfileResponse::Type }

#uri ⇒ String?

The Spotify URI for this user.

Returns:

  • (String, nil)


67
# File 'lib/spotted/models/user_retrieve_profile_response.rb', line 67

optional :uri, String