Class: Spotted::Models::Users::PlaylistCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/spotted/models/users/playlist_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, collaborative: nil, description: nil, published: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Spotted::Models::Users::PlaylistCreateParams for more details.

to

Parameters:

  • name (String) —

    The name for the new playlist, for example "Your Coolest Playlist". This name

  • collaborative (Boolean) (defaults to: nil) —

    Defaults to false. If true the playlist will be collaborative. _Note:

  • description (String) (defaults to: nil) —

    value for playlist description as displayed in Spotify Clients and in the Web AP

  • published (Boolean) (defaults to: nil) —

    The playlist's public/private status (if it should be added to the user's profil

  • request_options (Spotted::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/spotted/models/users/playlist_create_params.rb', line 46

Instance Attribute Details

#collaborative ⇒ Boolean?

Defaults to false. If true the playlist will be collaborative. Note: to create a collaborative playlist you must also set public to false. To create collaborative playlists you must have granted playlist-modify-private and playlist-modify-public scopes.

Returns:

  • (Boolean, nil)


27
# File 'lib/spotted/models/users/playlist_create_params.rb', line 27

optional :collaborative, Spotted::Internal::Type::Boolean

#description ⇒ String?

value for playlist description as displayed in Spotify Clients and in the Web API.

Returns:

  • (String, nil)


34
# File 'lib/spotted/models/users/playlist_create_params.rb', line 34

optional :description, String

#name ⇒ String

The name for the new playlist, for example "Your Coolest Playlist". This name does not need to be unique; a user may have several playlists with the same name.

Returns:

  • (String)


17
# File 'lib/spotted/models/users/playlist_create_params.rb', line 17

required :name, String

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


44
# File 'lib/spotted/models/users/playlist_create_params.rb', line 44

optional :published, Spotted::Internal::Type::Boolean