Class: Spotted::Models::Users::PlaylistCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/spotted/models/users/playlist_create_response.rb

Overview

Defined Under Namespace

Classes: Items, Owner, Tracks

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(display_name: nil) ⇒ Object

Some parameter documentations has been truncated, see Owner for more details.

The user who owns the playlist

Parameters:

  • display_name (String, nil) (defaults to: nil) —

    The name displayed on the user's profile. null if not available.



# File 'lib/spotted/models/users/playlist_create_response.rb', line 113

Instance Attribute Details

#collaborative ⇒ Boolean?

true if the owner allows other users to modify the playlist.

Returns:

  • (Boolean, nil)


19
# File 'lib/spotted/models/users/playlist_create_response.rb', line 19

optional :collaborative, Spotted::Internal::Type::Boolean

#description ⇒ String?

The playlist description. Only returned for modified, verified playlists, otherwise null.

Returns:

  • (String, nil)


26
# File 'lib/spotted/models/users/playlist_create_response.rb', line 26

optional :description, String, nil?: true

#external_urls ⇒ Spotted::Models::ExternalURLObject?

Known external URLs for this playlist.



32
# File 'lib/spotted/models/users/playlist_create_response.rb', line 32

optional :external_urls, -> { Spotted::ExternalURLObject }

#followers ⇒ Spotted::Models::FollowersObject?

Information about the followers of the playlist.



38
# File 'lib/spotted/models/users/playlist_create_response.rb', line 38

optional :followers, -> { Spotted::FollowersObject }

#href ⇒ String?

A link to the Web API endpoint providing full details of the playlist.

Returns:

  • (String, nil)


44
# File 'lib/spotted/models/users/playlist_create_response.rb', line 44

optional :href, String

#id ⇒ String?

The Spotify ID for the playlist.

Returns:

  • (String, nil)


13
# File 'lib/spotted/models/users/playlist_create_response.rb', line 13

optional :id, String

#images ⇒ Array<Spotted::Models::ImageObject>?

Images for the playlist. The array may be empty or contain up to three images. The images are returned by size in descending order. See Working with Playlists. Note: If returned, the source URL for the image (url) is temporary and will expire in less than a day.

Returns:



54
# File 'lib/spotted/models/users/playlist_create_response.rb', line 54

optional :images, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] }

#items ⇒ Spotted::Models::Users::PlaylistCreateResponse::Items?

The items of the playlist. Note: This field is only available for playlists owned by the current user or playlists the user is a collaborator of.



61
# File 'lib/spotted/models/users/playlist_create_response.rb', line 61

optional :items, -> { Spotted::Models::Users::PlaylistCreateResponse::Items }

#name ⇒ String?

The name of the playlist.

Returns:

  • (String, nil)


67
# File 'lib/spotted/models/users/playlist_create_response.rb', line 67

optional :name, String

#owner ⇒ Spotted::Models::Users::PlaylistCreateResponse::Owner?

The user who owns the playlist



73
# File 'lib/spotted/models/users/playlist_create_response.rb', line 73

optional :owner, -> { Spotted::Models::Users::PlaylistCreateResponse::Owner }

#published ⇒ Boolean?

The playlist's public/private status (if it should be added to the user's profile or not): true the playlist will be public, false the playlist will be private, null the playlist status is not relevant. For more about public/private status, see Working with Playlists

Returns:

  • (Boolean, nil)


83
# File 'lib/spotted/models/users/playlist_create_response.rb', line 83

optional :published, Spotted::Internal::Type::Boolean

#snapshot_id ⇒ String?

The version identifier for the current playlist. Can be supplied in other requests to target a specific playlist version

Returns:

  • (String, nil)


90
# File 'lib/spotted/models/users/playlist_create_response.rb', line 90

optional :snapshot_id, String

#tracks ⇒ Spotted::Models::Users::PlaylistCreateResponse::Tracks?

Deprecated.

Deprecated: Use items instead. The tracks of the playlist.



98
# File 'lib/spotted/models/users/playlist_create_response.rb', line 98

optional :tracks, -> { Spotted::Models::Users::PlaylistCreateResponse::Tracks }

#type ⇒ String?

The object type: "playlist"

Returns:

  • (String, nil)


104
# File 'lib/spotted/models/users/playlist_create_response.rb', line 104

optional :type, String

#uri ⇒ String?

The Spotify URI for the playlist.

Returns:

  • (String, nil)


111
# File 'lib/spotted/models/users/playlist_create_response.rb', line 111

optional :uri, String