Class: Spotted::Models::Me::PlayerStartPlaybackParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::Me::PlayerStartPlaybackParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/spotted/models/me/player_start_playback_params.rb
Overview
Instance Attribute Summary collapse
-
#context_uri ⇒ String?
Optional.
-
#device_id ⇒ String?
The id of the device this command is targeting.
-
#offset ⇒ Hash{Symbol=>Object}?
Optional.
-
#position_ms ⇒ Integer?
Indicates from what position to start playback.
-
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's profile or not):
truethe playlist will be public,falsethe playlist will be private,nullthe playlist status is not relevant. -
#uris ⇒ Array<String>?
Optional.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(device_id: nil, context_uri: nil, offset: nil, position_ms: nil, published: nil, uris: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PlayerStartPlaybackParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(device_id: nil, context_uri: nil, offset: nil, position_ms: nil, published: nil, uris: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Spotted::Models::Me::PlayerStartPlaybackParams for more details.
|
|
# File 'lib/spotted/models/me/player_start_playback_params.rb', line 60
|
Instance Attribute Details
#context_uri ⇒ String?
Optional. Spotify URI of the context to play. Valid contexts are albums, artists
& playlists. {context_uri:"spotify:album:1Je1IMUlBXcx1Fz0WE7oPT"}
23 |
# File 'lib/spotted/models/me/player_start_playback_params.rb', line 23 optional :context_uri, String |
#device_id ⇒ String?
The id of the device this command is targeting. If not supplied, the user's currently active device is the target.
16 |
# File 'lib/spotted/models/me/player_start_playback_params.rb', line 16 optional :device_id, String |
#offset ⇒ Hash{Symbol=>Object}?
Optional. Indicates from where in the context playback should start. Only
available when context_uri corresponds to an album or playlist object "position"
is zero based and can’t be negative. Example: "offset": {"position": 5} "uri"
is a string representing the uri of the item to start at. Example:
"offset": {"uri": "spotify:track:1301WleyT98MSxVHPZCA6M"}
33 |
# File 'lib/spotted/models/me/player_start_playback_params.rb', line 33 optional :offset, Spotted::Internal::Type::HashOf[Spotted::Internal::Type::Unknown] |
#position_ms ⇒ Integer?
Indicates from what position to start playback. Must be a positive number. Passing in a position that is greater than the length of the track will cause the player to start playing the next song.
41 |
# File 'lib/spotted/models/me/player_start_playback_params.rb', line 41 optional :position_ms, Integer |
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's
profile or not): true the playlist will be public, false the playlist will
be private, null the playlist status is not relevant. For more about
public/private status, see
Working with Playlists
51 |
# File 'lib/spotted/models/me/player_start_playback_params.rb', line 51 optional :published, Spotted::Internal::Type::Boolean |
#uris ⇒ Array<String>?
Optional. A JSON array of the Spotify track URIs to play. For example:
{"uris": ["spotify:track:4iV5W9uYEdYUVa79Axb7Rh", "spotify:track:1301WleyT98MSxVHPZCA6M"]}
58 |
# File 'lib/spotted/models/me/player_start_playback_params.rb', line 58 optional :uris, Spotted::Internal::Type::ArrayOf[String] |