Class: Spotted::Models::Me::TrackSaveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::Me::TrackSaveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/spotted/models/me/track_save_params.rb
Overview
Defined Under Namespace
Classes: TimestampedID
Instance Attribute Summary collapse
-
#ids ⇒ Array<String>
A JSON array of the Spotify IDs.
-
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's profile or not):
truethe playlist will be public,falsethe playlist will be private,nullthe playlist status is not relevant. -
#timestamped_ids ⇒ Array<Spotted::Models::Me::TrackSaveParams::TimestampedID>?
A JSON array of objects containing track IDs with their corresponding timestamps.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Spotted::Internal::Type::BaseModel
Instance Attribute Details
#ids ⇒ Array<String>
A JSON array of the
Spotify IDs. For example:
["4iV5W9uYEdYUVa79Axb7Rh", "1301WleyT98MSxVHPZCA6M"]<br/>A maximum of 50 items
can be specified in one request. Note: if the timestamped_ids is present
in the body, any IDs listed in the query parameters (deprecated) or the ids
field in the body will be ignored.
20 |
# File 'lib/spotted/models/me/track_save_params.rb', line 20 required :ids, Spotted::Internal::Type::ArrayOf[String] |
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's
profile or not): true the playlist will be public, false the playlist will
be private, null the playlist status is not relevant. For more about
public/private status, see
Working with Playlists
30 |
# File 'lib/spotted/models/me/track_save_params.rb', line 30 optional :published, Spotted::Internal::Type::Boolean |
#timestamped_ids ⇒ Array<Spotted::Models::Me::TrackSaveParams::TimestampedID>?
A JSON array of objects containing track IDs with their corresponding
timestamps. Each object must include a track ID and an added_at timestamp.
This allows you to specify when tracks were added to maintain a specific
chronological order in the user's library.
A maximum of 50 items can be
specified in one request. Note: if the timestamped_ids is present in the
body, any IDs listed in the query parameters (deprecated) or the ids field in
the body will be ignored.
42 43 |
# File 'lib/spotted/models/me/track_save_params.rb', line 42 optional :timestamped_ids, -> { Spotted::Internal::Type::ArrayOf[Spotted::Me::TrackSaveParams::TimestampedID] } |