Class: Spotted::Models::TrackObject::Album
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Spotted::Models::TrackObject::Album
- Defined in:
- lib/spotted/models/track_object.rb
Overview
Defined Under Namespace
Modules: AlbumType, ReleaseDatePrecision
Instance Attribute Summary collapse
-
#album_type ⇒ Symbol, Spotted::Models::TrackObject::Album::AlbumType
The type of the album.
-
#artists ⇒ Array<Spotted::Models::SimplifiedArtistObject>
The artists of the album.
- #available_markets ⇒ Array<String> deprecated Deprecated.
-
#external_urls ⇒ Spotted::Models::ExternalURLObject
Known external URLs for this album.
-
#href ⇒ String
A link to the Web API endpoint providing full details of the album.
-
#id ⇒ String
The Spotify ID for the album.
-
#images ⇒ Array<Spotted::Models::ImageObject>
The cover art for the album in various sizes, widest first.
-
#name ⇒ String
The name of the album.
-
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's profile or not):
truethe playlist will be public,falsethe playlist will be private,nullthe playlist status is not relevant. -
#release_date ⇒ String
The date the album was first released.
-
#release_date_precision ⇒ Symbol, Spotted::Models::TrackObject::Album::ReleaseDatePrecision
The precision with which
release_datevalue is known. -
#restrictions ⇒ Spotted::Models::AlbumRestrictionObject?
Included in the response when a content restriction is applied.
-
#total_tracks ⇒ Integer
The number of tracks in the album.
-
#type ⇒ Symbol, :album
The object type.
-
#uri ⇒ String
The Spotify URI for the album.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, album_type:, artists:, available_markets:, external_urls:, href:, images:, name:, release_date:, release_date_precision:, total_tracks:, uri:, published: nil, restrictions: nil, type: :album) ⇒ Object
constructor
Some parameter documentations has been truncated, see Album for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, album_type:, artists:, available_markets:, external_urls:, href:, images:, name:, release_date:, release_date_precision:, total_tracks:, uri:, published: nil, restrictions: nil, type: :album) ⇒ Object
Some parameter documentations has been truncated, see Spotted::Models::TrackObject::Album for more details.
The album on which the track appears. The album object includes a link in href
to full information about the album.
|
|
# File 'lib/spotted/models/track_object.rb', line 318
|
Instance Attribute Details
#album_type ⇒ Symbol, Spotted::Models::TrackObject::Album::AlbumType
The type of the album.
226 |
# File 'lib/spotted/models/track_object.rb', line 226 required :album_type, enum: -> { Spotted::TrackObject::Album::AlbumType } |
#artists ⇒ Array<Spotted::Models::SimplifiedArtistObject>
The artists of the album. Each artist object includes a link in href to more
detailed information about the artist.
233 |
# File 'lib/spotted/models/track_object.rb', line 233 required :artists, -> { Spotted::Internal::Type::ArrayOf[Spotted::SimplifiedArtistObject] } |
#available_markets ⇒ Array<String>
The markets in which the album is available: ISO 3166-1 alpha-2 country codes. NOTE: an album is considered available in a market when at least 1 of its tracks is available in that market.
244 |
# File 'lib/spotted/models/track_object.rb', line 244 required :available_markets, Spotted::Internal::Type::ArrayOf[String] |
#external_urls ⇒ Spotted::Models::ExternalURLObject
Known external URLs for this album.
250 |
# File 'lib/spotted/models/track_object.rb', line 250 required :external_urls, -> { Spotted::ExternalURLObject } |
#href ⇒ String
A link to the Web API endpoint providing full details of the album.
256 |
# File 'lib/spotted/models/track_object.rb', line 256 required :href, String |
#id ⇒ String
The Spotify ID for the album.
220 |
# File 'lib/spotted/models/track_object.rb', line 220 required :id, String |
#images ⇒ Array<Spotted::Models::ImageObject>
The cover art for the album in various sizes, widest first.
262 |
# File 'lib/spotted/models/track_object.rb', line 262 required :images, -> { Spotted::Internal::Type::ArrayOf[Spotted::ImageObject] } |
#name ⇒ String
The name of the album. In case of an album takedown, the value may be an empty string.
269 |
# File 'lib/spotted/models/track_object.rb', line 269 required :name, String |
#published ⇒ Boolean?
The playlist's public/private status (if it should be added to the user's
profile or not): true the playlist will be public, false the playlist will
be private, null the playlist status is not relevant. For more about
public/private status, see
Working with Playlists
310 |
# File 'lib/spotted/models/track_object.rb', line 310 optional :published, Spotted::Internal::Type::Boolean |
#release_date ⇒ String
The date the album was first released.
275 |
# File 'lib/spotted/models/track_object.rb', line 275 required :release_date, String |
#release_date_precision ⇒ Symbol, Spotted::Models::TrackObject::Album::ReleaseDatePrecision
The precision with which release_date value is known.
281 |
# File 'lib/spotted/models/track_object.rb', line 281 required :release_date_precision, enum: -> { Spotted::TrackObject::Album::ReleaseDatePrecision } |
#restrictions ⇒ Spotted::Models::AlbumRestrictionObject?
Included in the response when a content restriction is applied.
316 |
# File 'lib/spotted/models/track_object.rb', line 316 optional :restrictions, -> { Spotted::AlbumRestrictionObject } |
#total_tracks ⇒ Integer
The number of tracks in the album.
287 |
# File 'lib/spotted/models/track_object.rb', line 287 required :total_tracks, Integer |
#type ⇒ Symbol, :album
The object type.
293 |
# File 'lib/spotted/models/track_object.rb', line 293 required :type, const: :album |
#uri ⇒ String
The Spotify URI for the album.
300 |
# File 'lib/spotted/models/track_object.rb', line 300 required :uri, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/spotted/models/track_object.rb', line 365
|